@@ -5,7 +5,7 @@ use File::Basename;
 use File::Spec;
 use vars qw /$VERSION @ISA/;
 
-$VERSION="0.03";
+$VERSION="0.9714";
 @ISA = 'MP3::Tag::__hasparent';
 
 =pod
@@ -57,7 +57,7 @@ sub new_fromdir {
     my $class = shift;
     my $h = shift;
     my $dir = $h->{dir};
-    my $found;
+    my ($found, $e);
     my $l = $h->get_config('cddb_files');
     for my $file (@$l) {
 	my $f = File::Spec->catdir($dir, $file);
@@ -66,10 +66,13 @@ sub new_fromdir {
     return unless $found;
     local *F;
     open F, "< $found" or die "Can't open `$found': $!";
+    if ($e = $h->get_config('decode_encoding_cddb_file') and $e->[0]) {
+      eval "binmode F, ':encoding($e->[0])'"; # old binmode won't compile...
+    }
     my @data = <F>;
     close F or die "Error closing `$found': $!";
     bless {filename => $found, data => \@data, track => shift,
-	   parent => $h->{parent}}, $class;    
+	   parent => $h->{parent}}, $class;
 }
 
 sub new {
@@ -123,6 +126,7 @@ sub return_parsed {
 	return $self->{parsed}{t_in_track}  if $what =~/^title_track/i;
 	return $self->{parsed}{extt}  if $what =~/^comment_track/i;
 	return $self->{parsed}{extd}  if $what =~/^comment_collection/i;
+	return $self->{parsed}{DISCID}  if $what =~/^cddb_id/i;
 	return $self->{parsed}{album}  if $what =~/^al/i;
 	return $self->{parsed}{artist} if $what =~/^a/i;
 	return $self->{parsed}{track}  if $what =~/^tr/i;
@@ -225,6 +229,7 @@ sub parse {
     @parsed{ qw( title artist album year comment track genre
 		 a_in_title t_in_track extt extd) } =
 	($tt, $aa, $t, $y, $c1, $track, $cat, $a_in_title, $t_in_track, $cc2, $cc1);
+    $parsed{DISCID} = $self->{fields}{DISCID};
     $self->{parsed} = \%parsed;
     $self->return_parsed($what);
 }
@@ -276,7 +281,7 @@ sub track {
   return $self->{track} if defined $self->{track};
   return if $self->{recursive} or not $self->parent_ok;
   local $self->{recursive} = 1;
-  return $self->{parent}->track;
+  return $self->{parent}->track1;
 }
 
 =item year()
@@ -328,4 +333,11 @@ sub genre {
     return shift->parse("genre");
 }
 
+for my $elt ( qw( cddb_id ) ) {
+  no strict 'refs';
+  *$elt = sub (;$) {
+    return shift->parse($elt);
+  }
+}
+
 1;
